#
# spec file for package os-autoinst
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           os-autoinst
Version:        4.5.1525413876.6c59528a
Release:        lp150.1.1
Summary:        OS-level test automation
License:        GPL-2.0+
Group:          Development/Tools/Other
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  opencv-devel
BuildRequires:  pkg-config
BuildRequires:  perl(Module::CPANfile)
BuildRequires:  perl(Perl::Tidy)
BuildRequires:  perl(Test::Compile)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(theoraenc)
# just for the test suite
BuildRequires:  qemu-tools
Requires:       /usr/bin/qemu-img
Requires:       git-core
Requires:       optipng
%{perl_requires}
Requires:       qemu >= 2.0.0
Requires:       tesseract-ocr
Requires:       withlock
%define t_requires perl(Carp::Always) perl(Data::Dump) perl(Crypt::DES) perl(JSON) perl(autodie) perl(Class::Accessor::Fast) perl(Exception::Class) perl(File::Which) perl(IPC::Run::Debug) perl(Net::DBus) perl(Net::SNMP) perl(Net::IP) perl(IPC::System::Simple) perl(Net::SSH2) perl(XML::LibXML) perl(Test::Output) perl(Test::Fatal) perl(Test::Warnings) perl(Pod::Coverage) perl(Test::Pod) perl(Test::MockModule) perl(Devel::Cover) perl(JSON::XS) perl(List::MoreUtils) perl(Test::Mock::Time) perl(Socket::MsgHdr)
BuildRequires:  %t_requires
Requires:       %t_requires
BuildRequires:  perl(Mojolicious)
Requires:       perl(Mojolicious) >= 5.60
# we shuffle around a lot of JSON, so make sure this is fast
# and the JSON modules have subtle differences and we only test against XS in production
Requires:       perl(JSON::XS)
Recommends:     /usr/bin/xkbcomp /usr/bin/Xvnc dumponlyconsole
Requires(pre):  %{_bindir}/getent
Requires(pre):  %{_sbindir}/useradd
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The OS-autoinst project aims at providing a means to run fully
automated tests. Especially to run tests of basic and low-level
operating system components such as bootloader, kernel, installer
and upgrade, which can not easily and safely be tested with other
automated testing frameworks. However, it can just as well be used
to test firefox and openoffice operation on top of a newly
installed OS.

%package openvswitch
Summary:        Openvswitch support for os-autoinst
Group:          Development/Tools/Other
Requires:       openvswitch
Requires:       openvswitch-switch
Requires:       os-autoinst

%description openvswitch
This package contains openvswitch support for os-autoinst.

%prep
%setup -q
sed -e 's,/bin/env python,/bin/python,' -i crop.py

%build
mkdir -p m4
autoreconf -f -i
%configure --docdir=%{_docdir}/%{name}
make INSTALLDIRS=vendor %{?_smp_mflags}

%install
%make_install INSTALLDIRS=vendor
# Replace version number from git to what's reported by the package
sed  -i 's/ my $thisversion = qx{git rev-parse HEAD};/ my $thisversion = "%{version}";/' %{buildroot}/usr/bin/isotovideo
# only internal stuff
rm %{buildroot}/usr/lib/os-autoinst/tools/{tidy,check_coverage,absolutize}
rm -r %{buildroot}/usr/lib/os-autoinst/tools/lib/perlcritic
#
ls -lR %buildroot
find %{buildroot} -type f -name .packlist -print0 | xargs -0 --no-run-if-empty rm -f
find %{buildroot} -depth -type d -and -not -name distri -print0 | xargs -0 --no-run-if-empty rmdir 2>/dev/null || true
%perl_gen_filelist
#
# service symlink
mkdir -p %{buildroot}%{_sbindir}
ln -s ../sbin/service %{buildroot}%{_sbindir}/rcos-autoinst-openvswitch
#
# we need the stale symlinks to point to git
export NO_BRP_STALE_LINK_ERROR=yes

%check
# disable code quality checks - not worth the time for package builds
sed '/perlcritic/d' -i Makefile
sed '/Perl::Critic/d' -i cpanfile
sed '/tidy/d' -i Makefile
rm tools/lib/perlcritic/Perl/Critic/Policy/*.pm

# don't require qemu within OBS
cp t/05-pod.t t/99-full-stack.t

# should work offline
for p in $(cpanfile-dump); do rpm -q --whatprovides "perl($p)"; done
make check VERBOSE=1

%pre openvswitch
%service_add_pre os-autoinst-openvswitch.service

%post openvswitch
%service_add_post os-autoinst-openvswitch.service

%preun openvswitch
%service_del_preun os-autoinst-openvswitch.service

%postun openvswitch
%service_del_postun os-autoinst-openvswitch.service

%files -f %{name}.files
%defattr(-,root,root)
%{_docdir}/os-autoinst
%dir %{_libexecdir}/os-autoinst
%{_libexecdir}/os-autoinst/videoencoder
%{_libexecdir}/os-autoinst/basetest.pm
#
%{_libexecdir}/os-autoinst/dmidata
#
%{_libexecdir}/os-autoinst/bmwqemu.pm
%{_libexecdir}/os-autoinst/commands.pm
%{_libexecdir}/os-autoinst/distribution.pm
%{_libexecdir}/os-autoinst/testapi.pm
%{_libexecdir}/os-autoinst/mmapi.pm
%{_libexecdir}/os-autoinst/lockapi.pm
%{_libexecdir}/os-autoinst/cv.pm
%{_libexecdir}/os-autoinst/ocr.pm
%{_libexecdir}/os-autoinst/needle.pm
%{_libexecdir}/os-autoinst/osutils.pm
%{_libexecdir}/os-autoinst/myjsonrpc.pm
%{_libexecdir}/os-autoinst/backend
%{_libexecdir}/os-autoinst/OpenQA
%{_libexecdir}/os-autoinst/consoles
%dir %{_libexecdir}/os-autoinst/tools
%{_libexecdir}/os-autoinst/tools/preparepool
%{_libexecdir}/os-autoinst/autotest.pm
%{_libexecdir}/os-autoinst/crop.py

%files openvswitch
%defattr(-,root,root)
%{_libexecdir}/os-autoinst/os-autoinst-openvswitch
/usr/lib/systemd/system/os-autoinst-openvswitch.service
%config /etc/dbus-1/system.d/org.opensuse.os_autoinst.switch.conf
%{_sbindir}/rcos-autoinst-openvswitch

%changelog
* Fri May  4 2018 okurz@suse.com
- Update to version 4.5.1525413876.6c59528a:
  * Allow environment variable to point to OPENQA_LIBPATH (#959)
  * isotovideo: Add support to forward command line parameters as test settings (#950)
  * testapi: Output all arguments in log_call (#957)
* Thu Apr 26 2018 okurz@suse.com
- Update to version 4.5.1524736170.cc9d9ff2:
  * Add proceed_on_failure option (#954)
  * svirt KVM: Set <on_reboot> to 'destroy' (#956)
  * Set distribution earlier in isotovideo (#955)
  * mention TIMEOUT_SCALE in dock/backend_vars.asciidoc (#951)
  * testapi: Correct comment references to exception 'FailedNeedle'
  * Fix missing text thumbnail after needle related test failures
  * Do not quote -append qemu parameter
* Mon Apr 23 2018 okurz@suse.com
- Update to version 4.5.1524160420.7b402a0a:
  * testapi: Improve documentation for "wait_screen_change" (#943)
* Thu Apr 19 2018 okurz@suse.com
- Update to version 4.5.1523984252.2f46f2e2:
  * Bump testapi version as per change to select_console (#946)
  * Allow passing parameters to activate_console method (#945)
* Mon Apr  9 2018 okurz@suse.com
- Update to version 4.5.1523276311.2588e578:
  * Update current test module details when cancelling running job (#941)
  * Add OFFLINE_SUT mode to QEMU backend (#940)
  * Prints the isotovideo version and interface number
  * Merge qemu output failure conditions (#936)
  * Add test option _SKIP_POST_FAIL_HOOKS to save time on test development (#938)
  * Remove specific qemu code (#934)
  * Add username parameter for sshCommand
  * Allow setting console tty and other args (#933)
  * Move code from autotest to basetest
  * Add message to the invocation of the die function
  * Cleverness is not maintanable
  * Search for patterns in the SERIAL file and raise failures
* Tue Mar  6 2018 okurz@suse.com
- Update to version 4.5.1520265920.6728b435:
  * Tries to guess which qemu executable should use via WORKER_CLASS (#931)
  * Remove support for backend.crashed file (#930)
  * qemu: enable discard support for disks
  * Add support to override HDDMODEL per disk (#928)
* Sat Mar  3 2018 okurz@suse.com
- Update to version 4.5.1519457089.09762e3e:
  * testapi: Refactor script_output into distribution.pm and fix race (#926)
  * Use a fixed version of perltidy (#927)
  * Avoid broken perltidy in cpanfile
* Sat Feb 17 2018 okurz@suse.com
- Update to version 4.5.1518780731.3ca7dc34:
  * Do not fail on chattr failures (#924)
  * qemu: disable CoW for the HDD image directory (#790)
  * get_ssh_output and get_cmd_output return array in list context (#916)
  * Avoid letting the kids get loose. (#919)
  * Don't add floppy for arm/aarch (#923)
  * wip -- test to prevent double typing echo on virtio-console
  * Correct VNC stall threshold variable name (#922)
  * Check runcmd return status (#898)
  * testapi: Correct spelling mistake
  * testapi: Ensure script_output only returns the actual ouput of the executed script
  * tinycv: Add test for send_with_fd
  * testapi: Allow memory dump any time
  * qemu: Increase memory dump performance
  * tinycv: Add send_with_fd utility function
* Mon Jan 29 2018 okurz@suse.com
- Update to version 4.5.1516891126.e9d61c6d:
  * qemu: Die unless mandatory variable WORKER_HOSTNAME is set in NBF (#914)
  * Extract function which will retrun VM's host IP (#913)
* Tue Jan 23 2018 okurz@suse.com
- Update to version 4.5.1516628925.5467a37f:
  * Add single quote if parameter contains whitespace (#911)
  * Remove commented code (#912)
* Sat Jan 20 2018 okurz@suse.com
- Update to version 4.5.1516396050.1f10a0db:
  * Try to load OpenQA::Parser if present and parse extra test files. Add also support for xUnit and LTP
* Tue Jan 16 2018 okurz@suse.com
- Update to version 4.5.1516095934.1b1283ad:
  * Move and increase sleep time between ipmi power actions
  * Add variable to define stall treshold
  * Add variable to don't power of the machine after test
  * Increase the limits for checking the VNC console. (#906)
  * Makefile.am: Fix install directory for RunArgs.pm (#907)
* Sat Jan 13 2018 okurz@suse.com
- Update to version 4.5.1515766826.5f24243a:
  * Limit the execution time for save_memory_dump
  * Update documentation for save_storage_drives
  * Memory dumps are only callable from post_fail-hook
  * Add RunArgs to the Makefile
  * Display interface version when using --version
  * fix use of initialized value
* Tue Jan  9 2018 okurz@suse.com
- Update to version 4.5.1515414371.04e17fdf:
  * Ignore WORKER_HOSTNAME for qemu explicitly (#903)
  * Polling the read socket in the capture loop (#902)
* Fri Dec 22 2017 okurz@suse.com
- Update to version 4.5.1513942030.1c7bb3f5:
  * Do not reset NUMDISKS if RAIDLEVEL is not present (#901)
  * svirt: Add {start,stop}_serial_grab interface (#899)
  * Retidy - perltidy 20171214 changed output (#896)
  * Simply ignore '\r' in type string (#894)
  * Change the logs timestamp to ISO8601. (#893)
  * Add method to get files content and integration test
  * Add possibility to share files on worker directly
  * Add RunArgs to loadtest (#887)
  * Remove empty miniatures. (#891)
  * Fix error checking on load_snapshot and remove sleep (#890)
  * Drop all hmp commands and use qmp exclusively
  * [POC] Wrap HMP commands with QMP's human-monitor-command
  * Distinguish modules name in a test run if it's a duplicate (#884)
* Fri Dec 15 2017 coolo@suse.com
- disable perltidy and perlcritic checks during build
* Tue Nov 28 2017 okurz@suse.com
- Update to version 4.5.1511858414.576c33f6:
  * Fix quoting bug in type_command support (#886)
  * Extend lockapi barrier_wait to accept also parameters, and add support to check_dead_job (#880)
* Mon Nov 27 2017 okurz@suse.com
- Update to version 4.5.1511530266.fe4b1c52:
  * Fix snd2png check on TW: don't use PNM but PNG (#885)
  * Fix test failures on Tumbleweed (#883)
  * add debian ovmf to locations array
  * Add offline mode for script_output
  * Xen: Support multiple HDDs
  * svirt: Set NUMDISKS=4 when RAIDLEVEL is defined
  * Replacement of hot filehandlers for Mojo::Log (#876)
* Mon Nov 27 2017 coolo@suse.com
- bump to 4.5 to be in sync with openQA
* Thu Nov  2 2017 okurz@suse.com
- Update to version 4.4.1508936943.39adc5eb:
  * Fix scale_timeout call in wait_serial function
  * sshVirtsh: Hide confusing errors about undefined machines (#866)
  * avoid accidentally cleaning (#865)
  * Generalize x11_start_program with standard array argument (#863)
  * Remove unused reload_needles property in backend
  * Allow set_var to reevaluate needles
  * Add option to exit early for test schedule evaluation (#853)
  * Prevent diag message about _EXIT_AFTER_SCHEDULE if not requested
  * Make sure select_console on broken vnc fails (#872)
  * Introduce check_recorded_sound method (#873)
* Wed Sep 20 2017 coolo@suse.com
- add Test::Mock::Time require
* Wed Sep 20 2017 okurz@suse.com
- Update to version 4.4.1505909574.e0b4d014:
  * Correct validate_script_output test to actually test something
  * Add test for wait_still_screen
  * testapi: Add 'no_wait' option to wait_still_screen
  * Fix warning in test about 'prototype mismatch'
  * Allow type_string to wait_still_screen
  * Use hash ref in query_isotovideo
  * Add test for wait_idle in full stack test.
  * consoles: s3270: Make debug output of queue content less noisy
  * Update API document referring function type_string
  * Remove typing tests from integration tests (#857)
* Sat Jun 17 2017 stefan.bruens@rwth-aachen.de
- Add dependency on matching perl version, as the tinycv module is
  installed in a version dependent path
- Drop bogus conditionals, suse_version <= 132 will never match
* Thu Mar 23 2017 santiago.zarate@suse.com
- Inline replacement for version parameter on isotovideo
* Sun Mar 12 2017 oholecek@suse.com
- new perl(Test::Warnings) dependency
* Wed Sep  7 2016 oholecek@suse.com
- new perl(Devel::Cover) dependency
- package os-autoinst/tools/check_coverage tool
* Sat Jul  9 2016 coolo@suse.com
- update base version to 4.4 to express the new isotovideo API
  towards the worker
* Mon May 30 2016 oholecek@suse.com
- new perl(Test::MockModule) dependency
* Mon Feb 15 2016 oholecek@suse.com
- new perl(Test::Output) dependency
* Thu Jan 14 2016 oholecek@suse.com
- update base version to 4.3
* Tue Dec  8 2015 coolo@suse.com
- add snd2png
* Fri Nov 27 2015 coolo@suse.com
- new dependencies
* Tue Nov 24 2015 coolo@suse.com
- disable perlcritic outside of Factory - too useless to test with
  old perlcritic versions
* Tue Nov 24 2015 coolo@suse.com
- adapt file list
* Tue Nov 17 2015 coolo@suse.com
- remove gone files from file list
* Tue Aug 25 2015 lnussel@suse.de
- require tesseract-ocr on >= 13.2
* Thu Jul  9 2015 nadvornik@suse.com
- created os-autoinst-openvswitch subpackage
* Tue Mar 10 2015 oholecek@suse.com
- add mmapi.pm
* Sun Mar  1 2015 oholecek@suse.com
- add lockapi.pm
* Thu Feb 19 2015 lnussel@suse.de
- remove fetchneedles call. now in openQA
* Wed Jan 28 2015 coolo@suse.com
- make it version 4
* Thu Nov 27 2014 coolo@suse.com
- add videoencoder
* Thu Nov 27 2014 coolo@suse.com
- add distribution.pm
* Tue Nov 25 2014 coolo@suse.com
- recommend multimon too
* Tue Nov 25 2014 coolo@suse.com
- add testapi.pm to the file list
* Mon Nov 24 2014 coolo@suse.com
- recommend eatmydata for performance
* Mon Aug 18 2014 lnussel@suse.de
- adjust filelist for removed files
* Mon Jul 28 2014 lnussel@suse.de
- require qemu >= 2.0.0
* Tue Jul  8 2014 lnussel@suse.de
- include VNC.pm in file list
- add Crypt::DES to deps
* Tue Apr  8 2014 coolo@suse.com
- remove tidy script
* Tue Mar 25 2014 lnussel@suse.de
- remove rpc.pl from file list
* Wed Mar 12 2014 coolo@suse.com
- require qemu-img, quite useful :)
* Wed Mar 12 2014 coolo@suse.com
- switch github url to os-autoinst orga
* Mon Mar 10 2014 tchvatal@suse.com
- Use devel dep over pkgconfig one to build with 11.4 opencv
* Mon Mar 10 2014 tchvatal@suse.com
- Cleanup with spec-cleaner and use requires(pre)
* Tue May 14 2013 lnussel@suse.de
- initial package
